@@ -6,7 +6,7 @@ import uuid
 import pickle
 import sys
 
-from bravado.exception import HTTPUnauthorized, HTTPBadRequest, HTTPNotFound
+from bravado.exception import HTTPBadGateway, HTTPUnauthorized, HTTPBadRequest, HTTPNotFound, HTTPGatewayTimeout
 
 
 class BitmexClient:
@@ -64,13 +64,15 @@ class BitmexClient:
                                                 ).result()[0][0]['price']
             self._last_currentprice[symbol] = price
             return price
-        except (IndexError, HTTPBadRequest) as e:
+        except (IndexError, HTTPBadRequest, HTTPGatewayTimeout, HTTPBadGateway) as e:
             if 'expired' in str(e):
                 # now = datetime.datetime.utcnow()
                 # print('Current price expired error. Time:', now, ' Server Time:', now.strftime("%m/%d/%Y, %H:%M:%S"), 'Returning last price.', flush=True)
                 print('Current price expired error. Returning last price.', flush=True)
+            else:
+                print('API error getting current price', e, flush=True)
             return self.last_current_price(symbol)
-
+        
     def last_current_price(self, symbol):
         if symbol in self._last_currentprice.keys():
             return self._last_currentprice[symbol]
