@@ -85,8 +85,7 @@ class Lotus:
                             elif self.client.open_contracts(symbol) < 0:
                                 print('Closing {} order.'.format(
                                     symbol), flush=True)
-                                close = self.order.close(
-                                    symbol, qty=-self.order.props[symbol]['qty'])
+                                close = self.order.close(symbol, qty=-self.order.props[symbol]['qty'])
                                 if close:
                                     print('Closed open Bot old short position in {}, because now the Bot\'s Position is long.'.format(
                                         symbol), flush=True)
@@ -111,7 +110,7 @@ class Lotus:
                             elif self.client.open_contracts(symbol) > 0:
                                 print('Closing order on {}.'.format(
                                     symbol), flush=True)
-                                close = self.order.close(qty=-self.order.props[symbol]['qty'])
+                                close = self.order.close(symbol, qty=-self.order.props[symbol]['qty'])
                                 if close:
                                     print('Closed open Bot old long position in {}, because now the Bot\'s Position is short.'.format(
                                         symbol), flush=True)
@@ -133,7 +132,7 @@ class Lotus:
                     elif signal in [-2, 2]:  # signal has pending order
                         if self.order.props[symbol]['wait_stop']:
                             print("Cancel old order {} first.".format(symbol))
-                            self.order.stoporder_cancel()  # cancel old order first
+                            self.order.stoporder_cancel(symbol)  # cancel old order first
                             time.sleep(3)
                         contracts = self.order.calc_pos_size(
                             symbol, abs(entry - stoploss))
